Welcome to Salary Stone's documentation!
======================================

Salary Stone is a project dedicated to helping people get paid fairly within the world of data science. Named based on the idea of the
Rosetta Stone the purpose of this module is to provide nlp and modeling based methods that convert job descriptions into expected salary
and resumes into recommendations on what could be learned to increase salary. 


Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
